==> testflows.core-1.9.230302.1003619.tar.gz: testflows.core-1.9.230302.1003619/testflows/_core/cli/colors.py <==
# Copyright (c) 2008-2011 Volvox Development Team
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# Author: Konstantin Lepa <konstantin.lepa@gmail.com>

"""ANSII Color formatting for output in terminal."""

import testflows.settings as settings

from testflows._core.contrib.x256 import x256

__ALL__ = [ 'colored', 'cprint' ]

ATTRIBUTES = dict(
        list(zip([
            'bold',
            'dim',
            '',
            'underline',
            'blink',
            '',
            'reverse',
            'concealed'
            ],
            list(range(1, 9))
            ))
        )
del ATTRIBUTES['']


HIGHLIGHTS = dict(
        list(zip([
            'on_grey',
            'on_red',
            'on_green',
            'on_yellow',
            'on_blue',
            'on_magenta',
            'on_cyan',
            'on_white'
            ],
            list(range(40, 48))
            ))
        )


COLORS = dict(
        list(zip([
            'grey',
            'red',
            'green',
            'yellow',
            'blue',
            'magenta',
            'cyan',
            'white',
            ],
            list(range(30, 38))
            ))
        )

def reset(no_colors=False):
    return '\033[0m' if not (no_colors and settings.no_colors) else ''

def cursor_hide(no_colors=False):
    return '\033[?25l' if not (no_colors and settings.no_colors) else ''

def cursor_up(no_colors=False):
    return '\033[A' if not (no_colors and settings.no_colors) else ''

def clear_screen(no_colors=False):
    return chr(27) + "[2J" + '\033[0;0H'  if not (no_colors and settings.no_colors) else ''

def red(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "red", on_color=on_color, attrs=attrs, no_colors=no_colors)

def green(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "green", on_color=on_color, attrs=attrs, no_colors=no_colors)

def yellow(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "yellow", on_color=on_color, attrs=attrs, no_colors=no_colors)

def blue(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "blue", on_color=on_color, attrs=attrs, no_colors=no_colors)

def cyan(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "cyan", on_color=on_color, attrs=attrs, no_colors=no_colors)

def white(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "white", on_color=on_color, attrs=attrs, no_colors=no_colors)

def color(text, color=None, on_color=None, attrs=None, no_colors=False):
    """Colorize text.

    Available text colors:
        red, green, yellow, blue, magenta, cyan, white.

    Available text highlights:
        on_red, on_green, on_yellow, on_blue, on_magenta, on_cyan, on_white.

    Available attributes:
        bold, dim, underline, blink, reverse, concealed.

    Example:
        colored('Hello, World!', 'red', 'on_grey', ['blue', 'blink'])
        colored('Hello, World!', 'green')
    """
    if no_colors or settings.no_colors:
        pass
    else:
        fmt_str = '\033[%dm%s'
        if color is not None:
            if type(color) in (tuple, list):
                # convert RGB to closest x256
                color_256 = x256.from_rgb(*color)
                text = '\x1b[38;5;%dm%s' % (color_256, text)
            else:
                text = fmt_str % (COLORS[color], text)

        if on_color is not None:
            text = fmt_str % (HIGHLIGHTS[on_color], text)

        if attrs is not None:
            for attr in attrs:
                text = fmt_str % (ATTRIBUTES[attr], text)

        text += reset()
    return text

==> testflows.core-2.0.240627.1135549.tar.gz: testflows.core-2.0.240627.1135549/testflows/_core/cli/colors.py <==
# Copyright (c) 2008-2011 Volvox Development Team
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# Author: Konstantin Lepa <konstantin.lepa@gmail.com>

"""ANSII Color formatting for output in terminal."""

import testflows.settings as settings

from testflows._core.contrib.x256 import x256

__ALL__ = ["colored", "cprint"]

ATTRIBUTES = dict(
    list(
        zip(
            ["bold", "dim", "", "underline", "blink", "", "reverse", "concealed"],
            list(range(1, 9)),
        )
    )
)
del ATTRIBUTES[""]


HIGHLIGHTS = dict(
    list(
        zip(
            [
                "on_grey",
                "on_red",
                "on_green",
                "on_yellow",
                "on_blue",
                "on_magenta",
                "on_cyan",
                "on_white",
            ],
            list(range(40, 48)),
        )
    )
)


COLORS = dict(
    list(
        zip(
            [
                "grey",
                "red",
                "green",
                "yellow",
                "blue",
                "magenta",
                "cyan",
                "white",
            ],
            list(range(30, 38)),
        )
    )
)


def reset(no_colors=False):
    return "\033[0m" if not (no_colors and settings.no_colors) else ""


def cursor_hide(no_colors=False):
    return "\033[?25l" if not (no_colors and settings.no_colors) else ""


def cursor_up(no_colors=False):
    return "\033[A" if not (no_colors and settings.no_colors) else ""


def clear_screen(no_colors=False):
    return (
        chr(27) + "[2J" + "\033[0;0H" if not (no_colors and settings.no_colors) else ""
    )


def red(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "red", on_color=on_color, attrs=attrs, no_colors=no_colors)


def green(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "green", on_color=on_color, attrs=attrs, no_colors=no_colors)


def yellow(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "yellow", on_color=on_color, attrs=attrs, no_colors=no_colors)


def blue(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "blue", on_color=on_color, attrs=attrs, no_colors=no_colors)


def cyan(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "cyan", on_color=on_color, attrs=attrs, no_colors=no_colors)


def white(text, on_color=None, attrs=None, no_colors=False):
    return color(text, "white", on_color=on_color, attrs=attrs, no_colors=no_colors)


def color(text, color=None, on_color=None, attrs=None, no_colors=False):
    """Colorize text.

    Available text colors:
        red, green, yellow, blue, magenta, cyan, white.

    Available text highlights:
        on_red, on_green, on_yellow, on_blue, on_magenta, on_cyan, on_white.

    Available attributes:
        bold, dim, underline, blink, reverse, concealed.

    Example:
        colored('Hello, World!', 'red', 'on_grey', ['blue', 'blink'])
        colored('Hello, World!', 'green')
    """
    if no_colors or settings.no_colors:
        pass
    else:
        fmt_str = "\033[%dm%s"
        if color is not None:
            if type(color) in (tuple, list):
                # convert RGB to closest x256
                color_256 = x256.from_rgb(*color)
                text = "\x1b[38;5;%dm%s" % (color_256, text)
            else:
                text = fmt_str % (COLORS[color], text)

        if on_color is not None:
            text = fmt_str % (HIGHLIGHTS[on_color], text)

        if attrs is not None:
            for attr in attrs:
                text = fmt_str % (ATTRIBUTES[attr], text)

        text += reset()
    return text
